#ifndef STAN__PROB__DISTRIBUTIONS__UNIVARIATE_HPP
#define STAN__PROB__DISTRIBUTIONS__UNIVARIATE_HPP

#include <stan/prob/distributions/univariate/continuous.hpp>
#include <stan/prob/distributions/univariate/discrete.hpp>

#endif
